:mod:`PolynomesCollege` --- Fonctions polynômes
===============================================
Le module :mod:`PolynomesCollege` introduit la classe :class:`Polynome` qui
permet de faire des calculs détaillés sur les polynômes.

Un objet Polynome peut être construit à partir d'une liste et d'une chaîne contenant une variable ou à partir d'une chaîne représentant le polynôme avec la variable choisie.

.. autoclass:: pyromaths.classes.PolynomesCollege.Polynome
    :members:
    :special-members:
..    :private-members:
      :undoc-members:
      :show-inheritance: